==> v4_navigation_engine-0.1.80.tar.gz: ios/Classes/NavigationV4 (1)/Navigation/MyNavigationContracts.swift <==
//
//  MyNavigationContracts.swift
//  NavigationUI
//
//  Created Hassine on 10/03/2020.
//  Copyright © 2020 com.mile. All rights reserved.
//

import UIKit
import CoreLocation
import MapboxDirections
import MapboxCoreNavigation
import Mapbox

//MARK: View -
/*
 Should replace "class" with "BaseViewProtocol" if available;
 & that will allow the View to act as a UIViewController;
 & Implement common view functions.
 */
/// MyNavigation Module View Protocol
protocol MyNavigationViewProtocol: class {
    // Update UI with value returned.
    /// Set the view Object of Type MyNavigationEntity
    func set(object: MyNavigationEntity)

    /// show the route to the Start Point
    func showRouteToStartpoint(route:Route,routeOptions: RouteOptions)
    
    /// show the route to the Start Point
    func showDirectRouteToStartpoint()

    /// show the route to the Start Point
    func showRoute(route:Route,routeOptions: RouteOptions, waypoints:[Waypoint]?)
    
    /// show the route to the Start Point
    func showOfflineRoute(route:Route,routeOptions: RouteOptions, waypoints:[Waypoint]?)

    /// show the route to the Start Point
    func updateAndStartRoute(route:Route,routeOptions: RouteOptions ,waypoints:[Waypoint]?)

    func updateAndStartOfflineRoute(route: Route,routeOptions: RouteOptions, waypoints: [Waypoint]?)
    
    /// show system Message
    func showAlertSystemMessage(title:String,message:String)
    
    ///
   
    
    ///
    func set(user:MyUser)
    

}

//MARK: Interactor -
/// MyNavigation Module Interactor Protocol
protocol MyNavigationInteractorProtocol {
    // Fetch Object from Data Layer
    func fetch(objectFor presenter: MyNavigationPresenterProtocol)
}

//MARK: Presenter -
/// MyNavigation Module Presenter Protocol
protocol MyNavigationPresenterProtocol {
    /// The presenter will fetch data from the Interactor thru implementing the Interactor fetch function.
    func fetch(objectFor view: MyNavigationViewProtocol)
    /// The Interactor will inform the Presenter a successful fetch.
    func interactor(_ interactor: MyNavigationInteractorProtocol, didFetch object: MyNavigationEntity)
    /// The Interactor will inform the Presenter a failed fetch.
    func interactor(_ interactor: MyNavigationInteractorProtocol, didFailWith error: Error)

    /// calculate route from your location to a point
    func calculateRoute(startPoint coordinate:CLLocationCoordinate2D,locale:String,measurementSystem: MeasurementSystem, objectFor view: MyNavigationViewProtocol)

    /// calculate route from list of points
    func calculateRoute(points : [CLLocationCoordinate2D],locale:String,measurementSystem: MeasurementSystem, objectFor view: MyNavigationViewProtocol,profileIdentifier:MBDirectionsProfileIdentifier?,firstCalculation:Bool)
    
    /// init Measurement Unit
    func initMeasurementSystem(measurementSystem:MeasurementSystem) -> Void
    ///  checkBestLanguage
    func checkBestLanguage(pois:[PointOfInterest]?) -> (LanguageRessource,String)
     /// initLocationManager Unit
    func initLocationManager(delegate:MyNavigationView) -> Void
 
    
    ///
    func polygonCircleForCoordinate(coordinate: CLLocationCoordinate2D, withMeterRadius: Double) -> MGLPolygon
    ///
    func calculateCoordinates(coordinate: CLLocationCoordinate2D, withMeterRadius: Double) -> [CLLocationCoordinate2D]
    ///
    func calculateRouteOffline(points: [CLLocationCoordinate2D], locale:String,measurementSystem: MeasurementSystem,objectFor view: MyNavigationViewProtocol, profileIdentifier:MBDirectionsProfileIdentifier?,firstCalculation:Bool,id:String)
    
    ///
   func projectOnNewReference(_ previousLocation: CLLocation, _ nextLocation: CLLocation, _ poiLocation: CLLocation) -> ProjectionUtils
    
}

//MARK: Router (aka: Wireframe) -
/// MyNavigation Module Router Protocol
protocol MyNavigationRouterProtocol {
    // Show Details of Entity Object coming from ParentView Controller.
    // func showDetailsFor(object: MyNavigationEntity, parentViewController viewController: UIViewController)
}

==> v4_navigation_engine-0.1.86.tar.gz: ios/Classes/NavigationV4 (1)/Navigation/MyNavigationContracts.swift <==
//
//  MyNavigationContracts.swift
//  NavigationUI
//
//  Created Hassine on 10/03/2020.
//  Copyright © 2020 com.mile. All rights reserved.
//

import UIKit
import CoreLocation
import MapboxDirections
import MapboxCoreNavigation
import Mapbox

//MARK: View -
/*
 Should replace "class" with "BaseViewProtocol" if available;
 & that will allow the View to act as a UIViewController;
 & Implement common view functions.
 */
/// MyNavigation Module View Protocol
protocol MyNavigationViewProtocol: class {
    // Update UI with value returned.
    /// Set the view Object of Type MyNavigationEntity
    func set(object: MyNavigationEntity)

    /// show the route to the Start Point
    func showRouteToStartpoint(route:Route,routeOptions: RouteOptions)
    
    /// show the route to the Start Point
    func showDirectRouteToStartpoint()

    /// show the route to the Start Point
    func showRoute(route:Route,routeOptions: RouteOptions, waypoints:[Waypoint]?)
    
    /// show the route to the Start Point
    func showOfflineRoute(route:Route,routeOptions: RouteOptions, waypoints:[Waypoint]?)

    /// show the route to the Start Point
    func updateAndStartRoute(route:Route,routeOptions: RouteOptions ,waypoints:[Waypoint]?)

    func updateAndStartOfflineRoute(route: Route,routeOptions: RouteOptions, waypoints: [Waypoint]?)
    
    /// show system Message
    func showAlertSystemMessage(title:String,message:String)
    
    ///
   
    
    ///
    func set(user:MyUser)
    

}

//MARK: Interactor -
/// MyNavigation Module Interactor Protocol
protocol MyNavigationInteractorProtocol {
    // Fetch Object from Data Layer
    func fetch(objectFor presenter: MyNavigationPresenterProtocol)
}

//MARK: Presenter -
/// MyNavigation Module Presenter Protocol
protocol MyNavigationPresenterProtocol {
    /// The presenter will fetch data from the Interactor thru implementing the Interactor fetch function.
    func fetch(objectFor view: MyNavigationViewProtocol)
    /// The Interactor will inform the Presenter a successful fetch.
    func interactor(_ interactor: MyNavigationInteractorProtocol, didFetch object: MyNavigationEntity)
    /// The Interactor will inform the Presenter a failed fetch.
    func interactor(_ interactor: MyNavigationInteractorProtocol, didFailWith error: Error)

    /// calculate route from your location to a point
    func calculateRoute(startPoint coordinate:CLLocationCoordinate2D,locale:String,measurementSystem: MeasurementSystem, objectFor view: MyNavigationViewProtocol)

    /// calculate route from list of points
    func calculateRoute(points : [CLLocationCoordinate2D],locale:String,measurementSystem: MeasurementSystem, objectFor view: MyNavigationViewProtocol,profileIdentifier:MBDirectionsProfileIdentifier?,firstCalculation:Bool)
    
    /// init Measurement Unit
    func initMeasurementSystem(measurementSystem:MeasurementSystem) -> Void
    ///  checkBestLanguage
    func checkBestLanguage(languages:[String]?) -> (LanguageRessource,String)
     /// initLocationManager Unit
    func initLocationManager(delegate:MyNavigationView) -> Void
 
    
    ///
    func polygonCircleForCoordinate(coordinate: CLLocationCoordinate2D, withMeterRadius: Double) -> MGLPolygon
    ///
    func calculateCoordinates(coordinate: CLLocationCoordinate2D, withMeterRadius: Double) -> [CLLocationCoordinate2D]
    ///
    func calculateRouteOffline(points: [CLLocationCoordinate2D], locale:String,measurementSystem: MeasurementSystem,objectFor view: MyNavigationViewProtocol, profileIdentifier:MBDirectionsProfileIdentifier?,firstCalculation:Bool,id:String)
    
    ///
   func projectOnNewReference(_ previousLocation: CLLocation, _ nextLocation: CLLocation, _ poiLocation: CLLocation) -> ProjectionUtils
    
}

//MARK: Router (aka: Wireframe) -
/// MyNavigation Module Router Protocol
protocol MyNavigationRouterProtocol {
    // Show Details of Entity Object coming from ParentView Controller.
    // func showDetailsFor(object: MyNavigationEntity, parentViewController viewController: UIViewController)
}
